@@ -43,6 +43,7 @@ FACTOR = "Factor"
 OFFSET = "Offset"
 TOLERANCE = "Tolerance"
 SETPOINT = "Setpoint"
+PREVIOUS = "Previous"
 ALL = "*"
 DISPLAY = "display"
 IMAGE = "Image"
@@ -416,3 +417,8 @@ ATTR_FINISHED_AT = u"Finished at"
 ATTR_REQUESTED_FILES = u"Requested files"
 ATTR_SYNCED_FILES = u"Synced files"
 ATTR_METADATA = u"Metadata"
+ATTR_LOGFILE = u"Logfile"
+ATTR_HEADER = u"Header"
+ATTR_LAST_LOG_LINE = u"Last log line"
+ATTR_INTERVAL = u"Interval"
+ATTR_LOGGING = u"Logging"
\ No newline at end of file
