@@ -93,6 +93,7 @@ class Attribute(dict):
         self[DESCRIPTION] = description
         self[VALUE] = default_value
         self[SETPOINT] = None
+        self[PREVIOUS] = None
         self.update(kwargs)
 
     def _update_set_time(self):
@@ -107,6 +108,10 @@ class Attribute(dict):
 
     def __setitem__(self, k, v):
         if k == VALUE:
+            try:
+                self[PREVIOUS] = self[VALUE]
+            except KeyError:
+                pass
             if isinstance(v, units.Quantity):
                 try:
                     v = v.to(self[UNIT]).m
