@@ -5,6 +5,7 @@ import numpy as np
 from bidict import frozenbidict
 from pint.errors import UndefinedUnitError
 
+import kamzik3
 from kamzik3 import DeviceUnitError
 from kamzik3.constants import *
 from kamzik3.devices.deviceChannel import DeviceChannel
@@ -226,10 +227,10 @@ class DeviceKohzu(DeviceSocket):
         if callback is not None:
             self.handle_readout_callback(callback, command, readout_buffer)
         if token:
-            self.device_server.push_message(self.device_id, [command, readout_buffer], token)
+            kamzik3.session.publisher.push_message(self.device_id, [command, readout_buffer], token)
             for observer in self._observers[:]:
                 if isinstance(observer, DeviceKohzuChannel):
-                    self.device_server.push_message(observer.device_id, [command, readout_buffer], token)
+                    kamzik3.session.publisher.push_message(observer.device_id, [command, readout_buffer], token)
 
 
 class DeviceKohzuChannel(DeviceChannel):
@@ -396,10 +397,8 @@ class DeviceKohzuChannel(DeviceChannel):
             elif attribute == ATTR_PULSE_READ and not self.get_value(ATTR_READ_ENCODER):
                 self.set_raw_value(ATTR_POSITION, value * self[ATTR_STEP_RESOLUTION][VALUE])
             elif attribute == ATTR_POSITION_LOWER_LIMIT:
-                value = self[ATTR_POSITION].remove_offset_factor(value)
                 self.set_attribute([ATTR_POSITION, MIN], value)
             elif attribute == ATTR_POSITION_UPPER_LIMIT:
-                value = self[ATTR_POSITION].remove_offset_factor(value)
                 self.set_attribute([ATTR_POSITION, MAX], value)
             elif attribute == ATTR_STATE:
                 if int(value[0]) == 0:
