@@ -5,6 +5,7 @@ from threading import Thread, Event
 import numpy as np
 from pint.errors import UndefinedUnitError
 
+import kamzik3
 from kamzik3 import DeviceError, DeviceUnitError, units
 from kamzik3.constants import *
 from kamzik3.devices.deviceChannel import DeviceChannel
@@ -158,10 +159,10 @@ class DeviceLexium(DeviceSocket):
         if callback is not None:
             self.handle_readout_callback(callback, command, readout_buffer)
         if token:
-            self.device_server.push_message(self.device_id, [command, readout_buffer], token)
+            kamzik3.session.publisher.push_message(self.device_id, [command, readout_buffer], token)
             for observer in self._observers[:]:
                 if isinstance(observer, DeviceLexiumChannel):
-                    self.device_server.push_message(observer.device_id, [command, readout_buffer], token)
+                    kamzik3.session.publisher.push_message(observer.device_id, [command, readout_buffer], token)
                     break
 
     def handle_command(self, command, output):
@@ -516,7 +517,7 @@ class DeviceLexiumChannel(DeviceChannel):
         else:
             self.poll_command(u"PR I4\r", 200)
 
-        while not self.referencing_stop.wait(100e-3):
+        while not self.referencing_stop.wait(0.1):
             if stage == 0:  # Drive with maximum veloctiy to the HW limit
                 self.slew(maximum_velocity * direction)
                 stage = 1
@@ -539,10 +540,12 @@ class DeviceLexiumChannel(DeviceChannel):
             elif stage == 4 and self.get_value(ATTR_USE_MARK_INDEX) and self.get_value(ATTR_INDEX_MARK):
                 self.remove_poll_command(u"PR I6\r", 200)
                 self.stop()
+                time.sleep(0.3)
                 position = units.Quantity(self.config.get("reference_position", 0))
                 self.reset_position(str(position))
             elif stage == 4 and not self.get_value(ATTR_USE_MARK_INDEX) and not self.get_value(limit_switch):
                 self.stop()
+                time.sleep(0.3)
                 position = units.Quantity(self.config.get("reference_position", 0))
                 self.reset_position(str(position))
 
