@@ -316,6 +316,10 @@ class DeviceSession(Device):
         self.logger.info("Control loops closed")
 
     def stop(self):
+        """
+        Stop and disconnect all devices in Session
+        :return: None
+        """
         self.stop_polling()
 
         if self.server is not None:
@@ -392,7 +396,7 @@ class DeviceSession(Device):
     def clear_cache_folder(self):
         """
         Clear all files from current '.cache' folder.
-        :return:
+        :return: None
         """
         folder = self.get_value(ATTR_CACHE_DIRECTORY)
         for filename in os.listdir(folder):
