@@ -13,13 +13,13 @@ class DeviceSocket(asynchat.async_chat, Device):
     ac_out_buffer_size = 4096
     host = None
     port = None
-    send_lock = Lock()
 
     def __init__(self, host, port, device_id=None, config=None):
         Device.__init__(self, device_id, config)
         self.asyncore_loop = control_asyncore_loop
         self.host = host
         self.port = port
+        self.send_lock = Lock()
         asynchat.async_chat.__init__(self)
         self.create_socket(socket.AF_INET, socket.SOCK_STREAM)
         self.socket.setblocking(False)
@@ -76,6 +76,7 @@ class DeviceSocket(asynchat.async_chat, Device):
         return asynchat.async_chat.close_when_done(self)
 
     def close(self):
+        self.socket.shutdown(socket.SHUT_RDWR)
         asynchat.async_chat.close(self)
         self.set_status(STATUS_DISCONNECTED)
 
