@@ -3,6 +3,7 @@ import time
 import numpy as np
 import serial
 
+import kamzik3
 from kamzik3 import units, WriteException
 from kamzik3.constants import *
 from kamzik3.devices.devicePort import DevicePort
@@ -58,7 +59,7 @@ class DeviceThermoCube(DeviceSocket):
         if callback is not None:
             self.handle_readout_callback(callback, command, readout_buffer)
         if token:
-            self.device_server.push_message(self.device_id, [command, readout_buffer], token)
+            kamzik3.session.publisher.push_message(self.device_id, [command, readout_buffer], token)
 
     def start_polling(self):
         DeviceSocket.start_polling(self)
