@@ -1,4 +1,3 @@
-from PyQt5.QtCore import pyqtSlot
 from PyQt5.QtWidgets import QSizePolicy
 
 from kamzik3.constants import *
@@ -29,7 +28,3 @@ class AttributeStringWidget(AttributeWidget):
 
     def get_widget_value(self):
         return self.input_widget.text()
-
-    @pyqtSlot("QString")
-    def set_unit(self, unit=None, reset=False):
-        return
