@@ -145,7 +145,7 @@ class MacroWidget(QWidget, YamlSerializable):
         if self.config.get("defaults", False):
             default_value = self.config["defaults"].get("Total steps", default_value)
         total_steps_widget = AttributeDisplayWidget("Total steps",
-                                                    Attribute(default_value, min_value=0, default_type=np.uint64),
+                                                    Attribute(default_value=default_value, min_value=0, default_type=np.uint64),
                                                     config={"label_width": 110})
         self.total_steps_set_widget.layout().addWidget(total_steps_widget.input_widget)
         self.total_steps_lock_button.toggled.connect(total_steps_widget.input_widget.setDisabled)
@@ -194,7 +194,7 @@ class MacroWidget(QWidget, YamlSerializable):
 
     def _show_random_deviation_widget(self, row):
         random_deviation_widget = AttributeDisplayWidget("Random deviation",
-                                                         Attribute(0, decimals=2, default_type=np.float16,
+                                                         Attribute(default_value=0, decimals=2, default_type=np.float16,
                                                                    min_value=0,
                                                                    max_value=100, unit=u"%"),
                                                          config={"static_unit": True, "label_width": 110})
@@ -206,7 +206,7 @@ class MacroWidget(QWidget, YamlSerializable):
 
     def _show_wait_after_widget(self, row):
         wait_after_widget = AttributeDisplayWidget("Wait after",
-                                                   Attribute(0, decimals=0, default_type=np.float64, min_value=0,
+                                                   Attribute(default_value=0, decimals=0, default_type=np.float64, min_value=0,
                                                              unit=u"ms",
                                                              description="Set waiting time after each step."),
                                                    config={"static_unit": False, "label_width": 110})
@@ -217,7 +217,7 @@ class MacroWidget(QWidget, YamlSerializable):
         return wait_after_widget
 
     def _show_repeat_widget(self, row):
-        repeat_widget = AttributeDisplayWidget("Repeat", Attribute(0, default_type=np.uint64,
+        repeat_widget = AttributeDisplayWidget("Repeat", Attribute(default_value=0, default_type=np.uint64,
                                                                    description="Repeat step after first execution. Set number of repeats.\r\nEach step is executed at least ones"),
                                                config={"label_width": 110})
         self.layout().addWidget(repeat_widget.label_widget, row, 0)
@@ -231,7 +231,7 @@ class MacroWidget(QWidget, YamlSerializable):
         if self.config.get("defaults", False):
             default_value = self.config["defaults"].get("retry", default_value)
         retry_widget = AttributeDisplayWidget("Retry step",
-                                              Attribute(default_value, default_type=np.uint32, min_value=0,
+                                              Attribute(default_value=int(default_value), default_type=np.uint32, min_value=0,
                                                         description="In case of error, retry_count step again.\r\nSet maximum number of retries before throwing an error."),
                                               config={"static_unit": True, "label_width": 110})
         self.layout().addWidget(retry_widget.label_widget, row, 0)
@@ -245,7 +245,7 @@ class MacroWidget(QWidget, YamlSerializable):
         if self.config.get("defaults", False):
             default_value = self.config["defaults"].get("busy_timeout", default_value)
         busy_timeout_widget = AttributeDisplayWidget("Busy timeout",
-                                                     Attribute(default_value, decimals=0, default_type=np.float64,
+                                                     Attribute(default_value=float(default_value), decimals=0, default_type=np.float64,
                                                                min_value=0,
                                                                unit=u"ms",
                                                                description="Maximum waiting time for device to change from IDLE to BUSY status. Otherwise consider step as DONE."),
