@@ -8,6 +8,8 @@ from kamzik3.devices.attribute import Attribute
 from kamzik3.macro.common import Common
 
 
+# TODO: Implement ramping of value step
+
 class Step(Common):
 
     def __init__(self, common_id, repeat_count=0, wait_after=units.Quantity(0, "s"), retry_count=0, trigger_log=True):
@@ -24,7 +26,7 @@ class Step(Common):
         self.start_timer()
         if self.get_state() == STOPPED:
             return
-        super(Step, self).done()
+        self.done()
 
     def repeat(self):
         super(Step, self).repeat()
@@ -34,7 +36,7 @@ class Step(Common):
         self.start_timer()
         if self.get_state() == STOPPED:
             return
-        super(Step, self).done()
+        self.done()
 
     def body(self):
         raise NotImplementedError()
@@ -108,8 +110,8 @@ class StepDeviceAttribute(StepSetpoint):
             if not self.device.in_statuses(READY_DEVICE_STATUSES):
                 raise DeviceError(u"Device {} is not ready".format(self.device_id))
             # Attach callback for attribute and status changes
-            self.device.attach_attribute_callback(self.attribute, self.check_attribute_set)
-            self.device.attach_attribute_callback(ATTR_STATUS, self.check_device_status)
+            self.device.attach_attribute_callback(self.attribute, self.check_attribute_set, key_filter=VALUE)
+            self.device.attach_attribute_callback(ATTR_STATUS, self.check_device_status, key_filter=VALUE)
             # Set device's attribute to desired setpoint
             self.device.set_attribute(self.attribute + [VALUE], self.setpoint, callback=self.on_value_set)
             # Check if reached setpoint or timed out
@@ -148,29 +150,27 @@ class StepDeviceAttribute(StepSetpoint):
     def get_output(self):
         return self.device.get_attribute(self.attribute).value()
 
-    def check_attribute_set(self, key, value):
-        if key == VALUE:
-            # Check if value is within setpoint tolerants
-            if self.check_value_on_setpoint(self.device_attribute.value()):
-                self.device_setpoint_reached_flag = True
-            else:
-                self.device_setpoint_reached_flag = False
-            # Reset check_timeout
-            if not self.device_status_idle_flag:
-                with self.timeout_lock:
-                    self.check_timeout = 0
-
-    def check_device_status(self, key, value):
-        if key == VALUE:
-            # Check if device is idle
-            if value in IDLE_DEVICE_STATUSES:
-                self.device_status_idle_flag = True
-            else:
-                self.device_status_idle_flag = False
-            # Reset check_timeout
+    def check_attribute_set(self, value):
+        # Check if value is within setpoint tolerants
+        if self.check_value_on_setpoint(self.device_attribute.value()):
+            self.device_setpoint_reached_flag = True
+        else:
+            self.device_setpoint_reached_flag = False
+        # Reset check_timeout
+        if not self.device_status_idle_flag:
             with self.timeout_lock:
                 self.check_timeout = 0
 
+    def check_device_status(self, value):
+        # Check if device is idle
+        if value in IDLE_DEVICE_STATUSES:
+            self.device_status_idle_flag = True
+        else:
+            self.device_status_idle_flag = False
+        # Reset check_timeout
+        with self.timeout_lock:
+            self.check_timeout = 0
+
     def on_value_set(self, key, value):
         # Check for error when setting setpoint
         if key == RESPONSE_ERROR:
@@ -264,8 +264,8 @@ class StepDeviceAttributeNumerical(StepSetpointNumerical):
             if self.check_value_on_setpoint(self.device_attribute.value()):
                 return
             # Attach callback for attribute and status changes
-            self.device.attach_attribute_callback(self.attribute, self.check_attribute_set)
-            self.device.attach_attribute_callback(ATTR_STATUS, self.check_device_status)
+            self.device.attach_attribute_callback(self.attribute, self.check_attribute_set, key_filter=VALUE)
+            self.device.attach_attribute_callback(ATTR_STATUS, self.check_device_status, key_filter=VALUE)
             # Set device's attribute to desired setpoint
             setpoint = self.device_attribute.convert_units(self.setpoint)
             self.device.set_attribute(self.attribute + [VALUE], setpoint.m, callback=self.on_value_set)
@@ -309,28 +309,26 @@ class StepDeviceAttributeNumerical(StepSetpointNumerical):
         device = kamzik3.session.get_device(self.device_id)
         return "{}".format(device.get_attribute(self.attribute).value())
 
-    def check_attribute_set(self, key, value):
-        if key == VALUE:
-            # Check if value is within setpoint tolerants
-            if self.check_value_on_setpoint(self.device_attribute.value()):
-                self.device_setpoint_reached_flag = True
-            else:
-                self.device_setpoint_reached_flag = False
-            # Reset check_timeout when device is busy
-            if not self.device_status_idle_flag:
-                with self.timeout_lock:
-                    self.check_timeout = 0
+    def check_attribute_set(self, value):
+        # Check if value is within setpoint tolerants
+        if self.check_value_on_setpoint(self.device_attribute.value()):
+            self.device_setpoint_reached_flag = True
+        else:
+            self.device_setpoint_reached_flag = False
+        # Reset check_timeout when device is busy
+        if not self.device_status_idle_flag:
+            with self.timeout_lock:
+                self.check_timeout = 0
 
-    def check_device_status(self, key, value):
-        if key == VALUE:
-            # Check if device is idle
-            if value in IDLE_DEVICE_STATUSES:
-                self.device_status_idle_flag = True
-            else:
-                self.device_status_idle_flag = False
-            # Reset check_timeout
-            # with self.timeout_lock:
-            #     self.check_timeout = 0
+    def check_device_status(self, value):
+        # Check if device is idle
+        if value in IDLE_DEVICE_STATUSES:
+            self.device_status_idle_flag = True
+        else:
+            self.device_status_idle_flag = False
+        # Reset check_timeout
+        # with self.timeout_lock:
+        #     self.check_timeout = 0
 
     def on_value_set(self, key, value):
         # Check for error when setting setpoint
@@ -390,7 +388,7 @@ class StepDeviceMethod(Step):
             if not self.device.in_statuses(READY_DEVICE_STATUSES):
                 raise DeviceError(u"Device {} is not ready".format(self.device_id))
             # Attach callback for attribute and status changes
-            self.device.attach_attribute_callback(ATTR_STATUS, self.check_device_status)
+            self.device.attach_attribute_callback(ATTR_STATUS, self.check_device_status, key_filter=VALUE)
             # Set device's attribute to desired setpoint
             self.device_method(**self.method_parameters)
             # Check if reached setpoint or timed out
@@ -419,13 +417,12 @@ class StepDeviceMethod(Step):
         self.device = None
         self.device_method = None
 
-    def check_device_status(self, key, value):
-        if key == VALUE:
-            # Check if device is idle
-            if value in IDLE_DEVICE_STATUSES:
-                self.device_status_idle_flag = True
-            else:
-                self.device_status_idle_flag = False
+    def check_device_status(self, value):
+        # Check if device is idle
+        if value in IDLE_DEVICE_STATUSES:
+            self.device_status_idle_flag = True
+        else:
+            self.device_status_idle_flag = False
 
     def retry(self, retry_reason):
         try:
