@@ -3,7 +3,6 @@ import sys
 
 from PyQt5 import QtCore
 from PyQt5.QtCore import pyqtSignal, Qt
-from PyQt5.QtGui import QTextBlock
 from PyQt5.QtWidgets import QMessageBox, QInputDialog, QLineEdit, QDesktopWidget, QAbstractSpinBox, QSpinBox, \
     QDoubleSpinBox, QApplication, QPlainTextEdit
 
@@ -88,7 +87,15 @@ def show_prompt_dialog(prompt, title="", parent=None):
         return False
 
 
-def show_password_dialog(prompt, title="Insert password", default_text="", parent=None):
+def show_password_dialog(prompt, title="Type password", default_text="", parent=None):
+    """
+    Ask user for password input.
+    :param prompt: str
+    :param title: str
+    :param default_text: str
+    :param parent: QWidget
+    :return: str
+    """
     answer, ok = QInputDialog.getText(parent, title, prompt, QLineEdit.Password, default_text)
     if ok:
         return answer
@@ -98,7 +105,7 @@ def show_centralized_top(widget):
     """
     Show widget in center of current screen.
     Put widget on top of others.
-    Make it active even if minimalized.
+    Make it active even if minimized.
     :param widget: QWidget
     :return: None
     """
@@ -114,6 +121,11 @@ def show_centralized_top(widget):
 
 
 def init_qt_app(enable_hd_scaling=False):
+    """
+    Initialize QApplication with or without hd scaling factor
+    :param enable_hd_scaling: bool
+    :return: QApplication
+    """
     if enable_hd_scaling:
         os.environ["QT_AUTO_SCREEN_SCALE_FACTOR"] = "1"
     app = QApplication(sys.argv)
@@ -217,4 +229,4 @@ class CustomTextEdit(QPlainTextEdit):
         """
         if self.reset_on_blur:
             self.update_value()
-        return QPlainTextEdit.focusOutEvent(self, QFocusEvent)
\ No newline at end of file
+        return QPlainTextEdit.focusOutEvent(self, QFocusEvent)
